@@ -2,7 +2,7 @@ package Business::BalancedPayments;
 use Moo;
 with 'Business::BalancedPayments::HTTP';
 
-our $VERSION = '0.1101'; # VERSION
+our $VERSION = '0.1200'; # VERSION
 
 use Carp qw(croak);
 
@@ -11,7 +11,7 @@ has merchant    => (is => 'ro', lazy => 1, builder => '_build_merchant'   );
 has marketplace => (is => 'ro', lazy => 1, builder => '_build_marketplace');
 has logger      => (is => 'ro');
 
-has api_keys_uri     => (is => 'ro', default => sub { '/v1/api_keys'     });
+has customers_uri    => (is => 'ro', default => sub { '/v1/customers'    });
 has merchants_uri    => (is => 'ro', default => sub { '/v1/merchants'    });
 has marketplaces_uri => (is => 'ro', default => sub { '/v1/marketplaces' });
 
@@ -83,6 +83,19 @@ sub create_account {
     return $self->post($self->marketplace->{accounts_uri}, $account);
 }
 
+sub get_customer {
+    my ($self, $id) = @_;
+    croak 'The id param is missing' unless defined $id;
+    return $self->get($self->_uri($id, 'customers_uri'));
+}
+
+sub create_customer {
+    my ($self, $customer) = @_;
+    $customer ||= {};
+    croak 'The customer param must be a hashref' unless ref $customer eq 'HASH';
+    return $self->post($self->customers_uri, $customer);
+}
+
 sub update_account {
     my ($self, $account) = @_;
     croak 'The account param must be a hashref' unless ref $account eq 'HASH';
@@ -279,7 +292,7 @@ Business::BalancedPayments - BalancedPayments API bindings
 
 =head1 VERSION
 
-version 0.1101
+version 0.1200
 
 =head1 SYNOPSIS
 
